require

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 19, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Copyright © 2024 Omni Aura peyton@omniaura.co

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Equal

func Equal[T Equaler[T]](t *testing.T, want, got T)

func EqualErr

func EqualErr(t *testing.T, want, got error)

func NoError

func NoError(t *testing.T, err error)

func NotEqual

func NotEqual[T Equaler[T]](t *testing.T, want, got T)

func WantGot

func WantGot(sb *strings.Builder, want, got any)

func WantGotBoldQuotes

func WantGotBoldQuotes(sb *strings.Builder, want, got any)

Types

type Equaler

type Equaler[T any] interface {
	Equal(actual T) bool
}

Jump to