package
Version:
v0.5.3
Opens a new window with list of versions in this module.
Published: Feb 22, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Bool[T ~bool](b T) *T
func Int32[T ~int32](i T) *T
func Int64[T ~int64](i T) *T
func StrNil[T ~string](s T) *T
func Uint[T ~uint](i T) *T
func Uint32[T ~uint32](i T) *T
func Uint64[T ~uint64](i T) *T
Source Files
¶
Click to show internal directories.
Click to hide internal directories.