Documentation
¶
Overview ¶
Copyright © 2024 Omni Aura peyton@omniaura.co
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
Constants ¶
const ( KindUnset = iota KindTitle KindText // TODO: add var parameters // such as: // <!name string> // <!age int> // <!is_admin bool> // <!created_at datetime> // <!meeting_time time> // <!meeting_date date> // <!any_data any> // <!todos string list join="\n"> // <!weights float32 list join=","> // <!flags bool list join="," start="[" end="]"> // <!names join="\n"> KindVar KindRawBlock )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type T ¶
func (T) GetJSFmtVar ¶
Click to show internal directories.
Click to hide internal directories.